==> ecuacion-references-splib-web-tutorial-0.2.0-sources.jar: jp/ecuacion/referenceapps/splib/web/tutorial/domain/component/options/WayOfAddingOptionsController.java <==
package jp.ecuacion.referenceapps.splib.web.tutorial.domain.component.options;

import jakarta.validation.Valid;
import jp.ecuacion.referenceapps.splib.web.tutorial.domain.component.GreetingWithFirstNameRecord;
import jp.ecuacion.referenceapps.splib.web.tutorial.domain.component.options.WayOfAddingOptionsController.WayOfAddingOptionsForm;
import jp.ecuacion.splib.web.controller.SplibGeneral1FormController;
import jp.ecuacion.splib.web.form.SplibGeneralForm;
import jp.ecuacion.splib.web.service.SplibGeneral1FormDoNothingService;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;

@Controller
@Scope("prototype")
@RequestMapping("/public/01-component/options/wayOfAddingOptions")
public class WayOfAddingOptionsController extends
    SplibGeneral1FormController<WayOfAddingOptionsForm, SplibGeneral1FormDoNothingService<WayOfAddingOptionsForm>> {

  public WayOfAddingOptionsController() {
    super("wayOfAddingOptions",
        newContext().functionKinds("01-component/options").mainRootRecordName("greeting"));
  }

  /**
   * Provides a form for greeting page.
   * 
   * <p>It's okay for this class to be an independent one. This is just an saving of class files.</p>
   */
  public static class WayOfAddingOptionsForm extends SplibGeneralForm {

    @Valid
    private GreetingWithFirstNameRecord greeting = new GreetingWithFirstNameRecord("John");

    public GreetingWithFirstNameRecord getGreeting() {
      return greeting;
    }

    public void setGreeting(GreetingWithFirstNameRecord greeting) {
      this.greeting = greeting;
    }
  }
}

==> ecuacion-references-splib-web-tutorial-0.2.1-sources.jar: jp/ecuacion/referenceapps/splib/web/tutorial/domain/component/options/WayOfAddingOptionsController.java <==
package jp.ecuacion.referenceapps.splib.web.tutorial.domain.component.options;

import jakarta.validation.Valid;
import jp.ecuacion.referenceapps.splib.web.tutorial.domain.component.GreetingWithFirstNameRecord;
import jp.ecuacion.referenceapps.splib.web.tutorial.domain.component.options.WayOfAddingOptionsController.WayOfAddingOptionsForm;
import jp.ecuacion.splib.web.controller.SplibGeneral1FormController;
import jp.ecuacion.splib.web.form.SplibGeneralForm;
import jp.ecuacion.splib.web.service.SplibGeneral1FormDoNothingService;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;

@Controller
@Scope("prototype")
@RequestMapping("/public/01-component/options/wayOfAddingOptions")
//@formatter:off
public class WayOfAddingOptionsController 
    extends SplibGeneral1FormController<WayOfAddingOptionsForm, 
    SplibGeneral1FormDoNothingService<WayOfAddingOptionsForm>> {
  //@formatter:on

  public WayOfAddingOptionsController() {
    super("wayOfAddingOptions",
        newContext().functionKinds("01-component/options").mainRootRecordName("greeting"));
  }

  /**
   * Provides a form for greeting page.
   * 
   * <p>It's okay for this class to be an independent one. 
   *     This is just an saving of class files.</p>
   */
  public static class WayOfAddingOptionsForm extends SplibGeneralForm {

    @Valid
    private GreetingWithFirstNameRecord greeting = new GreetingWithFirstNameRecord("John");

    public GreetingWithFirstNameRecord getGreeting() {
      return greeting;
    }

    public void setGreeting(GreetingWithFirstNameRecord greeting) {
      this.greeting = greeting;
    }
  }
}
